@@ -29,6 +29,7 @@ from .settings import (
     MOONSTREAM_POLYGON_WEB3_PROVIDER_URI,
     MOONSTREAM_MUMBAI_WEB3_PROVIDER_URI,
     MOONSTREAM_XDAI_WEB3_PROVIDER_URI,
+    MOONSTREAM_WYRM_WEB3_PROVIDER_URI,
     NB_ACCESS_ID_HEADER,
     NB_DATA_SOURCE_HEADER,
     WEB3_CLIENT_REQUEST_TIMEOUT_SECONDS,
@@ -70,6 +71,8 @@ def connect(
             web3_uri = MOONSTREAM_MUMBAI_WEB3_PROVIDER_URI
         elif blockchain_type == AvailableBlockchainType.XDAI:
             web3_uri = MOONSTREAM_XDAI_WEB3_PROVIDER_URI
+        elif blockchain_type == AvailableBlockchainType.WYRM:
+            web3_uri = MOONSTREAM_WYRM_WEB3_PROVIDER_URI
         else:
             raise Exception("Wrong blockchain type provided for web3 URI")
 
@@ -123,8 +126,6 @@ def add_block(db_session, block: Any, blockchain_type: AvailableBlockchainType)
     )
     if blockchain_type == AvailableBlockchainType.XDAI:
         block_obj.author = block.author
-        block_obj.signature = block.signature
-        block_obj.step = block.step
 
     db_session.add(block_obj)
 
